# python-factorio-blueprints

[![PyPI version fury.io
](https://badge.fury.io/py/py-factorio-blueprints.svg)
](https://pypi.python.org/pypi/py-factorio-blueprints/)
[![GitHub release
](https://img.shields.io/github/release/tzwaan/python-factorio-blueprints.svg)
](https://GitHub.com/tzwaan/python-factorio-blueprints/releases/)

A python package for importing and editing factorio blueprint strings

Definitely not finished, but most basic blueprint functionality is supported.
